@@ -90,8 +90,10 @@ sub LDAP_CONTROL_SORTRESULT        () {	"1.2.840.113556.1.4.474"   }
 
 sub LDAP_CONTROL_VLVREQUEST        () { "2.16.840.1.113730.3.4.9"  }
 sub LDAP_CONTROL_VLVRESPONSE       () {	"2.16.840.1.113730.3.4.10" }
+sub LDAP_CONTROL_PROXYAUTHENTICATION () { "2.16.840.1.113730.3.4.12" }
 
 sub LDAP_CONTROL_PAGED		   () { "1.2.840.113556.1.4.319" }
+sub LDAP_CONTROL_TREE_DELETE	   () { "1.2.840.113556.1.4.805" }
 
 sub LDAP_CONTROL_MATCHEDVALS       () { "1.2.826.0.1.3344810.2.2" }
 
