@@ -9,7 +9,7 @@ use SelectSaver;
 require Net::LDAP::Entry;
 use vars qw($VERSION);
 
-$VERSION = "0.09";
+$VERSION = "0.13";
 
 my %mode = qw(w > r < a >>);
 
@@ -36,7 +36,9 @@ sub new {
     else {
       require Symbol;
       $fh = Symbol::gensym();
-      my $open = ($mode{$mode} || "<") . $file;
+      my $open = $file =~ /^\| | \|$/x
+	? $file
+	: (($mode{$mode} || "<") . $file);
       open($fh,$open) or return;
       $opened_fh = 1;
     }
@@ -60,6 +62,7 @@ sub new {
     file => "$file",
     opened_fh => $opened_fh,
     eof => 0,
+    write_count => ($mode eq 'a' and tell($fh) > 0) ? 1 : 0,
   };
 
   bless $self, $pkg;
@@ -79,13 +82,19 @@ sub _read_lines {
        $self->eof(1);
        return;
     }
-    $ln =~ s/^#.*\n//mg;
     $ln =~ s/\n //sg;
+    $ln =~ s/^#.*\n//mg;
     chomp($ln);
     $self->{_current_lines} = $ln;
     chomp(@ldif = split(/^/, $ln));
-    $self->{_next_lines} = scalar <$fh> || '';
-    $self->eof(1) unless $self->{_next_lines};
+    do {
+      $ln = scalar <$fh> || '';
+      $self->eof(1) unless $ln;
+      $ln =~ s/\n //sg;
+      $ln =~ s/^#.*\n//mg;
+      chomp($ln);
+      $self->{_next_lines} = $ln;
+    } until ($self->{_next_lines} || $self->eof());
   }
 
   @ldif;
@@ -105,6 +114,13 @@ sub _read_entry {
   return unless @ldif;
   shift @ldif if @ldif && $ldif[0] !~ /\D/;
 
+  if (@ldif and $ldif[0] =~ /^version:\s+(\d+)/) {
+    $self->{version} = $1;
+    shift @ldif;
+    return $self->_read_entry
+      unless @ldif;
+  }
+
   if (@ldif <= 1) {
      $self->_error("LDIF entry is not valid", @ldif);
      return;
@@ -356,7 +372,12 @@ sub write_entry {
       # Skip entry if there is nothing to write
       next if $type eq 'modify' and !@changes;
 
-      print "\n" if tell($self->{'fh'});
+      if ($self->{write_count}++) {
+	print "\n";
+      }
+      else {
+        print "version: $self->{version}\n" if defined $self->{version};
+      }
       _write_dn($entry->dn,$self->{'encode'},$wrap);
 
       print "changetype: $type\n";
@@ -394,9 +415,14 @@ sub write_entry {
     }
 
     else {
-       print "\n" if tell($self->{'fh'});
-       _write_dn($entry->dn,$self->{'encode'},$wrap);
-       _write_attrs($entry,$wrap,$lower);
+      if ($self->{write_count}++) {
+	print "\n";
+      }
+      else {
+        print "version: $self->{version}\n" if defined $self->{version};
+      }
+      _write_dn($entry->dn,$self->{'encode'},$wrap);
+      _write_attrs($entry,$wrap,$lower);
     }
   }
 
@@ -495,6 +521,11 @@ sub current_lines {
   $self->{_current_lines};
 }
 
+sub version {
+  my $self = shift;
+  $self->{version};
+}
+
 sub next_lines {
   my $self = shift;
   $self->{_next_lines};
